@@ -23,4 +23,8 @@ from .software.profilelist import ProfileListPlugin
 from .software.printdemon import PrintDemonPlugin
 from .system.timezone_data import TimezoneDataPlugin
 from .system.active_controlset import ActiveControlSetPlugin
+from .system.bootkey import BootKeyPlugin
+from .system.host_domain_name import HostDomainNamePlugin
 from .security.domain_sid import DomainSidPlugin
+from .sam.local_sid import LocalSidPlugin
+from .bcd.boot_entry_list import BootEntryListPlugin
