@@ -1,10 +1,10 @@
-import logbook
+import logging
 
 from regipy.hive_types import SOFTWARE_HIVE_TYPE
 from regipy.plugins.plugin import Plugin
 from regipy.utils import get_subkey_values_from_list, convert_wintime
 
-logger = logbook.Logger(__name__)
+logger = logging.getLogger(__name__)
 
 IMAGE_FILE_EXECUTION_OPTIONS = r'\Microsoft\Windows NT\CurrentVersion\Image File Execution Options'
 
