@@ -16,7 +16,7 @@ import pytz
 from regipy.exceptions import NoRegistrySubkeysException, RegistryKeyNotFoundException, RegipyGeneralException, \
     UnidentifiedHiveException
 from regipy.hive_types import NTUSER_HIVE_TYPE, SYSTEM_HIVE_TYPE, AMCACHE_HIVE_TYPE, SOFTWARE_HIVE_TYPE, \
-    SAM_HIVE_TYPE, SECURITY_HIVE_TYPE
+    SAM_HIVE_TYPE, SECURITY_HIVE_TYPE, BCD_HIVE_TYPE
 
 logger = logging.getLogger(__name__)
 
@@ -136,8 +136,10 @@ def identify_hive_type(name: str) -> str:
         return SOFTWARE_HIVE_TYPE
     elif hive_name == r'\systemroot\system32\config\sam':
         return SAM_HIVE_TYPE
-    elif hive_name == r'emroot\system32\config\security':
+    elif hive_name.endswith(r'\system32\config\security'):
         return SECURITY_HIVE_TYPE
+    elif hive_name.endswith(r'\boot\bcd'):
+        return BCD_HIVE_TYPE
     elif 'amcache' in hive_name.lower():
         return AMCACHE_HIVE_TYPE
     else:
